# belat

Converter of belarussian latin font to cyrillic (and back)

## Installing belat

1. Install `git`, `node >= 21`, `npm` and `python >= 3.9` (as for Windows, I advise you to use https://chocolatey.org)
2. Open command line
3. Enter:

```sh
git clone https://github.com/alex-rusakevich/belat.git
cd belat
inv install
```

If you are a developer, you may also install `husky`:

```sh
npm install
npx husky install
```

## Running
Run `belat.pyw` to run GUI program without console, or run `belat.py` to open GUI program with console. You can also run `cbelat.py` to open console-only version.

## Credits

The project uses `Fugue` Icons, thanks [Yusuke Kamiyamane](https://p.yusukekamiyamane.com/) for his great and free icon pack!

[![License: CC BY 3.0](https://img.shields.io/badge/License-CC_BY_3.0-lightgrey.svg)](https://creativecommons.org/licenses/by/3.0/)
